==> wmaker_0.92.0.orig.tar.gz: WindowMaker-0.92.0/src/extend_pixmaps.h <==
#include "wconfig.h"

static char *PRED_XKBGROUP1_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "........##",
    ".......###",
    "..########",
    "..########",
    "......####",
    ".....#####",
    "..########",
    "..########",
    "........##",
    "........##"
};

#ifdef LANGUAGE_TH
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "#..###..##",
    ".#..#.#..#",
    ".#...###..",
    "#...####..",
    "##..####..",
    "##..####..",
    "##..####..",
    "##..####..",
    "##..####..",
    "##.#####.#"
};
#elif defined LANGUAGE_SK
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "####..####",
    "####..####",
    "##......##",
    "##......##",
    "####..####",
    "#........#",
    "#........#",
    "####..####",
    "###....###",
    "##......##"};
#elif defined LANGUAGE_EL
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "##..######",
    "##..##....",
    "......####",
    "##..##....",
    "##..######",
    "..........",
    "##########",
    "..........",
    "##########",
    "##########"};
#else
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "##########",
    "#...##...#",
    "..........",
    "..........",
    "..........",
    "..........",
    "#........#",
    "##......##",
    "###....###",
    "####..####"
};
#endif

static char *PRED_XKBGROUP3_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "..........",
    "..........",
    "..##..##..",
    "..##..##..",
    "..........",
    "..........",
    "..######..",
    "...####...",
    "....##....",
    ".........."
};

static char *PRED_XKBGROUP4_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "..........",
    ".########.",
    ".#..##..#.",
    ".#..##..#.",
    ".########.",
    ".#......#.",
    ".##....##.",
    ".###..###.",
    ".########.",
    ".........."
};

==> wmaker_0.96.0.orig.tar.gz: WindowMaker-0.96.0/src/extend_pixmaps.h <==
#include "wconfig.h"

static char *PRED_XKBGROUP1_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "........##",
    ".......###",
    "..########",
    "..########",
    "......####",
    ".....#####",
    "..########",
    "..########",
    "........##",
    "........##"
};

#ifdef LANGUAGE_TH
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "#..###..##",
    ".#..#.#..#",
    ".#...###..",
    "#...####..",
    "##..####..",
    "##..####..",
    "##..####..",
    "##..####..",
    "##..####..",
    "##.#####.#"
};
#elif defined LANGUAGE_SK
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "####..####",
    "####..####",
    "##......##",
    "##......##",
    "####..####",
    "#........#",
    "#........#",
    "####..####",
    "###....###",
    "##......##"};
#elif defined LANGUAGE_EL
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "##..######",
    "##..##....",
    "......####",
    "##..##....",
    "##..######",
    "..........",
    "##########",
    "..........",
    "##########",
    "##########"};
#else
static char *PRED_XKBGROUP2_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "##########",
    "#...##...#",
    "..........",
    "..........",
    "..........",
    "..........",
    "#........#",
    "##......##",
    "###....###",
    "####..####"
};
#endif

static char *PRED_XKBGROUP3_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "..........",
    "..........",
    "..##..##..",
    "..##..##..",
    "..........",
    "..........",
    "..######..",
    "...####...",
    "....##....",
    ".........."
};

static char *PRED_XKBGROUP4_XPM[] = {
    "    10    10        2            1",
    ". c #000000",
    "# c None",
    "..........",
    ".########.",
    ".#..##..#.",
    ".#..##..#.",
    ".########.",
    ".#......#.",
    ".##....##.",
    ".###..###.",
    ".########.",
    ".........."
};


static char *NEXT_XKBGROUP1_XPM[] = {
"10 10 6 1",
" 	c None",
".	c #E0E0E0",
"+	c #7D7D7D",
"@	c #363636",
"#	c #080808",
"$	c #BDBDBD",
".........+",
"..@@@@@@++",
"..@####+++",
"..#+$$$$++",
"..###+.$++",
"..#++..$++",
"..#$.$$$++",
"..#@@@@+++",
".$+#####@@",
"+++++++@@@"};

static char *NEXT_XKBGROUP2_XPM[] = {
"10 10 6 1",
" 	c None",
".	c #E0E0E0",
"+	c #7D7D7D",
"@	c #BDBDBD",
"#	c #080808",
"$	c #363636",
".........+",
".@##@@$#++",
".#.+#+###+",
".#+######+",
".########+",
"..######++",
"..@####+++",
".@@@#$++++",
".@++#$++$$",
"+++++++$$$"};

static char *NEXT_XKBGROUP3_XPM[] = {
"10 10 6 1",
" 	c None",
".	c #E0E0E0",
"+	c #7D7D7D",
"@	c #BDBDBD",
"#	c #080808",
"$	c #363636",
".........+",
"..@####.++",
".@######.+",
".#.+##.+#+",
".#++##++#+",
".########+",
".##@##@##+",
".+##@@##$+",
".@+####$$$",
"+++++++$$$"};

static char *NEXT_XKBGROUP4_XPM[] = {
"10 10 6 1",
" 	c None",
".	c #E0E0E0",
"+	c #7D7D7D",
"@	c #BDBDBD",
"#	c #080808",
"$	c #363636",
".........+",
"..@####.++",
".@#@@@@#.+",
".##$@@#$#+",
".#$$@@$$#+",
".#@@@@++#+",
".#+#++#.#+",
".+#+##$#$+",
".@+####$$$",
"+++++++$$$"};
